# pyRealEstate

pyRealEstate is a library designed for data scientists working in the real estate industry. pyRealEstate is still currently under development but is aimed at providing functions to assist in the development and evaluation of AVM's. Below are some instructions on how to get started with pyRealEstate and some helpful links to descriptions and examples of all of PyRealEstates functionality 

## Installation

the pyRealEstate package is available on [PyPi](https://pypi.org/project/pyRealEstate). Simply run: 
```
pip install pyRealEstate
```
## AVM Evalutation Metrics
pyRealEstate can provide metrics on the evaluation of your AVM( AAutomated Valuation Model) such as the weighted mean sale ratio, COD (Coefficient Of Disspersion), and PRD ( Price Related Differential) please visit the wiki for detailed documentation [pyRealEstate Evaluation](https://github.com/Joshua-Data-Wizard/PyRealEstate/wiki/AVM-Evaluation-Metrics)

